package com.ruoyi.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.SysPointTier;

/**
 * 积分使用梯次Mapper接口
 *
 * @author ruoyi
 * @date 2025-05-28
 */
public interface SysPointTierMapper  extends BaseMapper<SysPointTier>
{
    /**
     * 查询积分使用梯次
     *
     * @param id 积分使用梯次主键
     * @return 积分使用梯次
     */
    public SysPointTier selectSysPointTierById(Long id);

    /**
     * 查询积分使用梯次列表
     *
     * @param sysPointTier 积分使用梯次
     * @return 积分使用梯次集合
     */
    public List<SysPointTier> selectSysPointTierList(SysPointTier sysPointTier);

    /**
     * 新增积分使用梯次
     *
     * @param sysPointTier 积分使用梯次
     * @return 结果
     */
    public int insertSysPointTier(SysPointTier sysPointTier);

    /**
     * 修改积分使用梯次
     *
     * @param sysPointTier 积分使用梯次
     * @return 结果
     */
    public int updateSysPointTier(SysPointTier sysPointTier);

    /**
     * 删除积分使用梯次
     *
     * @param id 积分使用梯次主键
     * @return 结果
     */
    public int deleteSysPointTierById(Long id);

    /**
     * 批量删除积分使用梯次
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysPointTierByIds(Long[] ids);
}
