package com.ruoyi.web.controller.system;
import java.util.Date;
import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysPointTier;
import com.ruoyi.system.service.ISysPointTierService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 积分使用梯次Controller
 *
 * @author ruoyi
 * @date 2025-05-28
 */
@RestController
@RequestMapping("/system/pointTier")
public class SysPointTierController extends BaseController
{
    @Autowired
    private ISysPointTierService sysPointTierService;

    /**
     * 查询积分使用梯次列表
     */
    @PreAuthorize("@ss.hasPermi('system:pointTier:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysPointTier sysPointTier)
    {
        startPage();
        List<SysPointTier> list = sysPointTierService.selectSysPointTierList(sysPointTier);
        return getDataTable(list);
    }

    /**
     * 导出积分使用梯次列表
     */
    @PreAuthorize("@ss.hasPermi('system:pointTier:export')")
    @Log(title = "积分使用梯次", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysPointTier sysPointTier)
    {
        List<SysPointTier> list = sysPointTierService.selectSysPointTierList(sysPointTier);
        ExcelUtil<SysPointTier> util = new ExcelUtil<SysPointTier>(SysPointTier.class);
        util.exportExcel(response, list, "积分使用梯次数据");
    }

    /**
     * 获取积分使用梯次详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:pointTier:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sysPointTierService.selectSysPointTierById(id));
    }

    /**
     * 新增积分使用梯次
     */
    @PreAuthorize("@ss.hasPermi('system:pointTier:add')")
    @Log(title = "积分使用梯次", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysPointTier sysPointTier)
    {
        sysPointTier.setCreateTime(new Date());
        return toAjax(sysPointTierService.insertSysPointTier(sysPointTier));
    }

    /**
     * 修改积分使用梯次
     */
    @PreAuthorize("@ss.hasPermi('system:pointTier:edit')")
    @Log(title = "积分使用梯次", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysPointTier sysPointTier)
    {
        return toAjax(sysPointTierService.updateSysPointTier(sysPointTier));
    }

    /**
     * 删除积分使用梯次
     */
    @PreAuthorize("@ss.hasPermi('system:pointTier:remove')")
    @Log(title = "积分使用梯次", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysPointTierService.deleteSysPointTierByIds(ids));
    }
}

